@@ -1,12 +1,12 @@
 package String::Validator::Password;
+$String::Validator::Password::VERSION = '1.96'; # TRIAL
+# ABSTRACT: String::Validator Password Checking Module.
 
-use 5.006;
+use 5.008;
 use strict;
 use warnings;
 no warnings qw(uninitialized) ;
-use String::Validator::Common;
-
-our $VERSION = '1.94';
+use String::Validator::Common 1.90;
 
 
 my $password_messages = {
@@ -24,11 +24,6 @@ my $password_messages = {
 		if ( $type eq 'num') { $type = 'numeric'}
 		return "character type $type is prohibited."
 	},
-	password_typelimit => sub {
-		my ($type, $limit) = @_;
-		if ( $type eq 'num') { $type = 'numeric'}
-		return "$type is limited to fewer than $limit" ;
-	},
 };
 
 sub new {
@@ -55,7 +50,7 @@ sub new {
     $self->{errstring} = '' ;
     bless $self, $class ;
     $self->{messages}
-        = String::Validator::Common::Messages(
+        = String::Validator::Common::_Messages(
         		$password_messages, $self->{language}, $self->{custom_messages} );
     return $self ;
 }
@@ -65,8 +60,9 @@ sub new {
 # Is/IsNot_Valid. May be invoked directly.
 sub Check{
     my ( $self, $string1, $string2 ) = @_ ;
-    if ( $self->CheckCommon( $string1, $string2 ) == 99 ) {
+    if ( $self->Start( $string1, $string2 ) == 99 ) {
         return $self->{ error } }
+    $self->Length;
 # The match operator cannot be directly used to count matches.
 # substitution does count replacements, and by removing all other
 # other character classes what is left over is "punct".
@@ -94,14 +90,14 @@ sub Check{
 			if ( $self->{ $num } )
 				{ $self->IncreaseErr(
 					$self->{messages}{password_typeprohibit}->($type) ) } }
-		elsif ( $self->{ $denied } > 1 ) {
-			if ( $self->{ $denied } <= $self->{ $num } ) {
-				$self->IncreaseErr(
-					$self->{messages}{password_typelimit}->(
-						$type, $self->{ $denied } ) )
-			}	}
+		# elsif ( $self->{ $denied } > 1 ) {
+		# 	if ( $self->{ $denied } <= $self->{ $num } ) {
+		# 		$self->IncreaseErr(
+		# 			$self->{messages}{password_typelimit}->(
+		# 				$type, $self->{ $denied } ) )
+		# 	}
+		# }
 	} #foreach ( lc num uc punct ).
-
 return $self->{ error } ;
 }
 
@@ -116,11 +112,11 @@ __END__
 
 =head1 NAME
 
-String::Validator::Password
+String::Validator::Password - String::Validator Password Checking Module.
 
 =head1 VERSION
 
-version 1.95
+version 1.96
 
 =head1 SYNOPSIS
 
@@ -138,8 +134,6 @@ String::Validator::Password - Check a string against a number of common password
 
 =head1 VERSION
 
-Version 1.94
-
 =head1 String::Validator Methods and Usage
 
 Provides and conforms to all of the standard String::Validator methods, please see
@@ -225,9 +219,7 @@ John Karr, C<< <brainbuz at brainbuz.org> >>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-string-validator-password at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=String-Validator-Password>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+Please submit Bug Reports and Patches via https://github.com/brainbuz/String-Validator.
 
 =head1 SUPPORT
 
